@@ -1,8 +1,8 @@
 package Reddit::Client;
 
-our $VERSION = '1.2814';
+our $VERSION = '1.2815';
 # TODO: make ispost, iscomment and get_type static
-# 1.2814-documentation update
+# 1.2815-documentation update
 # 1.281 -morecomments get_collapsed args
 # 1.281 -get_collapsed can also return morecomments
 # 1.28  -get_links_by_id
@@ -1679,13 +1679,25 @@ Approve a comment or post (moderator action).
 
 Ban a user from a subreddit. C<username> and C<subreddit> are required. Optional arguments include:
 
-* C<duration>: Duration in days. Range 1-999. If false or not provided, the ban is indefinite.
+=over
 
-* C<ban_message>: The message sent to the banned user. (Markdown is allowed.)
+=item duration
 
-* C<reason>: A short ban reason (100 characters max). On the website ban page, this matches the ban reason you would select from the dropdown menu. It is arbitrary: it doesn't have to match up with the reasons from the menu and can be blank. Only visible to moderators.
+Duration in days. Range 1-999. If false or not provided, the ban is indefinite.
 
-* C<note>: An optional note, 300 characters max. Only visible to moderators.
+=item ban_message
+
+The message sent to the banned user. (Markdown is allowed.)
+
+=item reason
+
+A short ban reason (100 characters max). On the website ban page, this matches the ban reason you would select from the dropdown menu. It is arbitrary: it doesn't have to match up with the reasons from the menu and can be blank. Only visible to moderators.
+
+=item note
+
+An optional note, 300 characters max. Only visible to moderators.
+
+=back
 
 A ban will overwrite any existing ban for that user. For example, to change the duration, you can call C<ban()> again with a new duration.
 
@@ -1711,23 +1723,27 @@ Returns a hash of information about the newly created multireddit.
 
 =over
 
-* C<name> The name of the multireddit. Maximum 50 characters. Only letters, numbers and underscores are allowed (and underscores cannot be the first character). Required.
+C<name> The name of the multireddit. Maximum 50 characters. Only letters, numbers and underscores are allowed (and underscores cannot be the first character). Required.
 
-* C<description> Description of the multi. This can contain markdown.
+C<description> Description of the multi. This can contain markdown.
 
-* C<visibility> One of 'private', 'public', or 'hidden'. Default 'private'.
+C<visibility> One of 'private', 'public', or 'hidden'. Default 'private'.
 
-* C<subreddits> or C<subs>: An array reference.
+C<subreddits> or C<subs>: An array reference.
 
 =back
 
 The remaining arguments don't currently do anything. It seems like at least some of them are intended for future mobile updates.
 
-* C<icon_name> If provided, must be one of the following values: 'art and design', 'ask', 'books', 'business', 'cars', 'comics', 'cute animals', 'diy', 'entertainment', 'food and drink', 'funny', 'games', 'grooming', 'health', 'life advice', 'military', 'models pinup', 'music', 'news', 'philosophy', 'pictures and gifs', 'science', 'shopping', 'sports', 'style', 'tech', 'travel', 'unusual stories', 'video', '', 'None'.
+=over
 
-* C<weighting_scheme> If provided, must be either 'classic' or 'fresh'.
+C<icon_name>: If provided, must be one of the following values: 'art and design', 'ask', 'books', 'business', 'cars', 'comics', 'cute animals', 'diy', 'entertainment', 'food and drink', 'funny', 'games', 'grooming', 'health', 'life advice', 'military', 'models pinup', 'music', 'news', 'philosophy', 'pictures and gifs', 'science', 'shopping', 'sports', 'style', 'tech', 'travel', 'unusual stories', 'video', '', 'None'.
 
-* C<key_color> A 6-character hex code. Defaults to CEE3F8.
+C<weighting_scheme>: If provided, must be either 'classic' or 'fresh'.
+
+C<key_color>: A 6-character hex code. Defaults to CEE3F8.
+
+=back
 
 =item delete 
 
@@ -1755,14 +1771,18 @@ Edit a multireddit. Will create a new multireddit if one with that name doesn't
 
     edit_wiki ( subreddit => $subreddit, page => $page, content => $content,
               [ previous => $previous_version_id, ] [ reason => $edit_reason, ] )
+
+=over
 	
-* C<page> is the page being edited.
+C<page> is the page being edited.
 
-* C<content> is the new page content. Can be empty but must be defined. Maximum 524,288 characters.
+C<content> is the new page content. Can be empty but must be defined. Maximum 524,288 characters.
 
-* C<reason> is the edit reason. Max 256 characters, will be truncated if longer. Optional.
+C<reason> is the edit reason. Max 256 characters, will be truncated if longer. Optional.
 
-* C<previous> is the ID of the intended previous version of the page; if provided, that is the version the page will be rolled back to in a rollback. However, there's no way to find out what this should be from the Reddit website, or currently from Reddit::Client either. Use it only if you know what you're doing.
+C<previous> is the ID of the intended previous version of the page; if provided, that is the version the page will be rolled back to in a rollback. However, there's no way to find out what this should be from the Reddit website, or currently from Reddit::Client either. Use it only if you know what you're doing.
+
+=back
 
 =item find_subreddits
 
@@ -1894,7 +1914,7 @@ edited: Things that have been edited recently.
 C<num_reports> contains the total number of reports. Reports themselves can be found in the C<mod_reports> and C<user_reports> properties. These are arrays of arrays, i.e.
 
     [ [ "Spam",  3 ], [ "report #2", 1 ] ]    # user_reports
-	[ [ "mod report", "moderator_name" ] ]    # mod_reports
+    [ [ "mod report", "moderator_name" ] ]    # mod_reports
 	
 The number with C<user_reports> is the number of times that particular report has been sent. This is mainly for duplicates that users have selected from the menu, for example "Spam".
 
@@ -2145,17 +2165,7 @@ Return the Reddit::Client version.
 
     vote ( $fullname, $direction )
 
-=begin html
-
-Vote on a post or comment. <code>$direction</code> can be 1, 0, or -1 (0 to clear votes).
-
-=end html
-
-=begin text
-
-Vote on a post or comment. Direction can be 1, 0, or -1 (0 to clear votes).
-
-=end text
+Vote on a post or comment. C<$direction> can be 1, 0, or -1 (0 to clear votes).
 
 =back
 
